@@ -5,10 +5,11 @@ use Mouse;
 use Lemonldap::NG::Common::UserAgent;
 use JSON qw(from_json to_json);
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.6';
 
 has ua => (
     is      => 'rw',
+    lazy    => 1,
     default => sub {
         return Lemonldap::NG::Common::UserAgent->new( $_[0]->{conf} );
     }
@@ -16,6 +17,13 @@ has ua => (
 
 sub restCall {
     my ( $self, $url, $content ) = @_;
+    $self->logger->debug("REST: trying to call $url with:");
+    eval {
+        foreach ( keys %$content ) {
+            $self->logger->debug(
+                " $_: " . ( /password/ ? '****' : $content->{$_} ) );
+        }
+    };
     my $hreq = HTTP::Request->new( POST => $url );
     $hreq->header( 'Content-Type' => 'application/json' );
     $hreq->content( to_json($content) );
@@ -23,7 +31,7 @@ sub restCall {
     unless ( $resp->is_success ) {
         die $resp->status_line;
     }
-    my $res = eval { from_json( $resp->content ) };
+    my $res = eval { from_json( $resp->content, { allow_nonref => 1 } ) };
     die "Bad REST response: $@" if ($@);
     return $res;
 }
